@@ -1,9 +1,9 @@
 import importlib.metadata
 
 from .rcmt import execute, execute_local, options_from_config
-from .run import Run
+from .task import Run, Task
 
-__all__ = ["Run", "execute", "execute_local", "options_from_config"]
+__all__ = ["Run", "Task", "execute", "execute_local", "options_from_config"]
 
 try:
     __version__ = importlib.metadata.version(__name__)
